import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;
const centerX = width / 2;
const centerY = height / 2;

const faceStrokeWidth = 20;
const faceColor = '#FABC79';



//**********Element1 - Eyes***************

const eyeOffsetX = 100;
const eyeOffsetY = -30;
const eyeRadius = 50;
const eyeStrokeWidth = 5;

const irisRadius = eyeRadius * 0.5;
const irisOffsetX = -irisRadius / 2 + 10;
const irisOffsetY = irisRadius / 2 - 7;
const irisColor = '#88C978';

const pupilRadius = eyeRadius * 0.4;
const pupilOffsetX = irisOffsetX - irisRadius / 4;
const pupilOffsetY = irisOffsetY + irisRadius / 4;

//*********Element2 - Eyebrows*************

const eyebrowOffsetX = -eyeRadius - 10;
const eyebrowOffsetY = -60;
const eyebrowWidth = 100;
const eyebrowHeight = 10;
const eyebrowRotation = 7;

//**********Element3 - Hair************

//https://www.google.com/url?sa=i&url=https%3A%2F%2Fdannyphantom.fandom.com%2Fwiki%2FDanny_Phantom_(character)&psig=AOvVaw3e8HXuMa2sRLYIV0zBsMQw&ust=1599091918088000&source=images&cd=vfe&ved=0CAIQjRxqFwoTCNi8hOCXyesCFQAAAAAdAAAAABAI
const hairPoints =
  -centerX * 0.5 +
  ',' +
  -centerY * 0.8 +
  ' ' +
  -centerX * 0.6 +
  ',' +
  -centerY * 0.1 +
  ' ' +
  -centerX * 0.4 +
  ',' +
  -centerY * 0.5 +
  ' ' +
  170 +
  ',' +
  -centerY * 0.4 +
  ' ' +
  -centerX * 0.05 +
  ',' +
  -centerY * 0.8 +
  ' ' +
  centerX * 0.6 +
  ',' +
  -centerY * 0.3 +
  ' ' +
  centerX * 0 +
  ',' +
  -centerY * 1.32 +
  ' ' +
  centerX * 0.3 +
  ',' +
  -centerY * 2 +
  ' ' +
  centerX * 0.1 +
  ',' +
  -centerY +
  ' ' +
  6 +
  ',' +
  -centerY * 1.1 +
  ' ' +
  centerX * 0.07 +
  ',' +
  -centerY * 1.3 +
  ' ';
const hairColor = 'black';
const hairStrokeColor = 'brown';
const hairStrokeWidth = 5;

//**************Element4 - Nose*************

const nosePoints =
  0 +
  ',' +
  -centerY * 0.2 +
  ' ' +
  centerX * 0.01 +
  ',' +
  centerY * 0.1 +
  ' ' +
  centerX * 0.05 +
  ',' +
  centerY * 0.1 +
  ' ' +
  centerX * 0.05 +
  ',' +
  centerY * 0.2 +
  ' ';
const noseStrokeWidth = 5;

//****************Element5 - Mouth************

const mouthWidth = 20;
const mouthRadius = 80;

const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI * 0.7)
  .endAngle(Math.PI * 1.3);

const App = () => (
  <svg width={width} height={height}>
    <g
      transform={`translate(${centerX},${centerY})`}
    >
//*************Element6 - Face************
      
      <circle
        r={centerY - faceStrokeWidth / 1.9}
        fill={faceColor}
        stroke="black"
        stroke-width={faceStrokeWidth}
      />

//********Part of Element1 - Left Eye********
      <circle
        cx={-eyeOffsetX}
        cy={eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        stroke-width={eyeStrokeWidth}
      />
      
//**********Element7 - Iris*********************
//**********Part of Element7 - Left Iris********
      <circle
        cx={-eyeOffsetX + irisOffsetX}
        cy={eyeOffsetY + irisOffsetY}
        r={irisRadius}
        fill={irisColor}
      />
      
//**********Element8 - Pupil*********************
//**********Part of Element8 - Left Pupil********
      <circle
        cx={-eyeOffsetX + pupilOffsetX}
        cy={eyeOffsetY + pupilOffsetY}
        r={pupilRadius}
        fill="black"
      />
      
//**********Part of Element1 - Right Eye*********
      <circle
        cx={eyeOffsetX}
        cy={eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        stroke-width={eyeStrokeWidth}
      />
      
//**********Part of Element7 - Right Iris********
      <circle
        cx={eyeOffsetX + irisOffsetX}
        cy={eyeOffsetY + irisOffsetY}
        r={irisRadius}
        fill={irisColor}
      />
      
//**********Part of Element8 - Right Pupil******
      <circle
        cx={eyeOffsetX + pupilOffsetX}
        cy={eyeOffsetY + pupilOffsetY}
        r={pupilRadius}
        fill="black"
      />
      
//**********Part of Element2 - Left Eyebrow******
      <rect
        width={eyebrowWidth}
        height={eyebrowHeight}
        x={-eyeOffsetX + eyebrowOffsetX}
        y={eyeOffsetY + eyebrowOffsetY}
        transform={`rotate(${eyebrowRotation})`}
      />
      
//**********Part of Element2 - Right Eyebrow********
      <rect
        width={eyebrowWidth}
        height={eyebrowHeight}
        x={eyeOffsetX + eyebrowOffsetX}
        y={eyeOffsetY + eyebrowOffsetY}
        transform={`rotate(${-eyebrowRotation})`}
      />
      
//***********Part of Element5 -  Mouth*****************
      <path
        d={mouthArc()}
        transform={`translate(${-20},${45})`}
      />
 
//************Element9 - Eyelashes*******************
      <line
        x1={60}
        y1={-60}
        x2={50}
        y2={-78}
        stroke = "black"
        stroke-width = '2.3'
      />
      <line
        x1={80}
        y1={-75}
        x2={70}
        y2={-87}
        stroke = "black"
        stroke-width = '2.3'
      />  
      <line
        x1={100}
        y1={-80}
        x2={90}
        y2={-95}
        stroke = "black"
        stroke-width = '2.3'
      />
      <line
        x1={120}
        y1={-75}
        x2={100}
        y2={-135}
        stroke = "black"
        stroke-width = '2.3'
      />
        <line
        x1={-140}
        y1={-62}
        x2={-150}
        y2={-80}
        stroke = "black"
        stroke-width = '2.3'
      />
        <line
        x1={-130}
        y1={-72}
        x2={-135}
        y2={-90}
        stroke = "black"
        stroke-width = '2.3'
      />
        <line
        x1={-110}
        y1={-82}
        x2={-115}
        y2={-94}
        stroke = "black"
        stroke-width = '2.3'
      />
       <line
        x1={-90}
        y1={-82}
        x2={-90}
        y2={-92}
        stroke = "black"
        stroke-width = '2.3'
      />
      
//************Element10 - Ear*****************
      
      <line
        x1={-300}
        y1={10}
        x2={-220}
        y2={-75}
        stroke = "black"
        stroke-width = '03'
      />
      <line
        x1={-230}
        y1={10}
        x2={-302.2}
        y2={10}
        stroke = "black"
        stroke-width = '03'
      />
      <line
        x1={300}
        y1={10}
        x2={110}
        y2={-225}
        stroke = "black"
        stroke-width = '03'
      />
      <line
        x1={230}
        y1={10}
        x2={302.2}
        y2={10}
        stroke = "black"
        stroke-width = '03'
      />
      
//**************Element11 - toungue**********
      
        <rect 
        x={-100/2}
        y={144*0.9}
        fill = 'red'
        opacity='1'
        stroke='black'
        stroke-width='6'
        width='80'
        height='80'
        
        rx='25'
        ry='80'
        />
      
//***********Part of Element4 - Nose************
      <polyline
        points={nosePoints}
        fill="none"
        stroke="black"
        stroke-width={noseStrokeWidth}
      />
      
//***********Part of Element3 - Hair**********
      <polygon
        points={hairPoints}
        fill={hairColor}
        opacity="1" //used for debugging
        stroke={hairStrokeColor}
        stroke-width={hairStrokeWidth}
      />
    </g>
  </svg>
);

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
